@@ -424,7 +424,7 @@ class Distributive(object):
     def performFormat(self):
         pass
 
-    def formatPartition(self, dev, format="ext4", label=""):
+    def formatPartition(self, dev, format="ext4", label="", boot=False):
         pass
 
     def rndString(self):
@@ -835,17 +835,23 @@ class FormatProcess(process):
     dos_id = "0"
     gpt_id = "0"
 
-    def __init__(self, dev, label=None):
+    def __init__(self, dev, label=None, boot=False):
         self.dev = dev
         self._label = label
+        self.boot = boot
         super(FormatProcess, self).__init__(*self.format_command())
 
     def format_command(self):
         cmd = getProgPath(self.format_util)
         if not cmd:
             raise DistributiveError(_("command '%s' not found") % cmd)
+
+        params = self.bootparam() if self.boot else self.param()
         return list(traverse(
-            [cmd] + [x for x in self.param() if x]))
+            [cmd] + [x for x in params if x]))
+
+    def bootparam(self):
+        return self.param()
 
     def param(self):
         return self.get_label(), self.dev
@@ -910,6 +916,12 @@ class FormatXfs(FormatProcessGeneric):
     def param(self):
         return self.get_label(), "-f", self.dev
 
+    def nosparse(self):
+        return "-i", "sparse=0"
+
+    def bootparam(self):
+        return self.get_label(), self.nosparse(), "-f", self.dev
+
 
 class FormatVfat(FormatProcess):
     dos_id = "0b"
@@ -1118,6 +1130,11 @@ class PartitionDistributive(Distributive):
                                filter(
                                    lambda x: x[NEEDFORMAT] and x[FS] != "bind",
                                    dataPartitions))
+        # if has separate /boot partition
+        if any("/boot" in mp for fs,dev,_id,mp in formatPartitions):
+            bootmp = "/boot"
+        else:
+            bootmp = "/"
         # format all get partition
         for fileSystem, dev, newID, mp in formatPartitions:
             if fileSystem == "swap":
@@ -1127,13 +1144,14 @@ class PartitionDistributive(Distributive):
                     fileSystem = "uefi"
                 if dev == self.partition:
                     self.formatPartition(dev, format=fileSystem,
-                                         label=self.rootLabel)
+                                         label=self.rootLabel,
+                                         boot= mp == bootmp)
                 else:
                     if mp == '/var/calculate':
                         self.formatPartition(dev, format=fileSystem,
                                              label="Calculate")
                     else:
-                        self.formatPartition(dev, format=fileSystem)
+                        self.formatPartition(dev, format=fileSystem, boot= mp == bootmp)
         # change system id for partitions
         changeidPartitions = map(lambda x: (x[NEWID], x[DEV], x[PARTTABLE]),
                                  filter(lambda x: x[NEWID],
@@ -1148,7 +1166,7 @@ class PartitionDistributive(Distributive):
             raise DistributiveError(
                 _("Failed to format %s: this partition is mounted") % dev)
 
-    def formatPartition(self, dev, format="ext4", label=""):
+    def formatPartition(self, dev, format="ext4", label="", boot=False):
         """Format partition"""
         if not format in self.format_map:
             raise DistributiveError(
@@ -1163,7 +1181,7 @@ class PartitionDistributive(Distributive):
             raise DistributiveError(_("Failed to format the partition") +
                                     " %s:\n%s" % (dev, _("Permission denied")))
 
-        format_process = self.format_map[format](dev, label)
+        format_process = self.format_map[format](dev, label=label, boot=boot)
         if format_process.failed():
             raise DistributiveError(
                 _("Failed to format the partition") +
@@ -1175,7 +1193,7 @@ class PartitionDistributive(Distributive):
             self.formatAllPartitions()
         elif self.isFormat:
             self.formatPartition(self.partition, format=self.fileSystem,
-                                 label=self.rootLabel)
+                                 label=self.rootLabel, boot=True)
             if self.systemId:
                 self.changeSystemID(self.partition, self.systemId,
                                     self.partitionTable)
