@@ -1179,7 +1179,8 @@ class VariableOsLocationDest(LocationHelper, Variable):
         ##########################
         # detect efi specifing
         ##########################
-        if "efi" in value:
+        reEfi = re.compile("/u?efi", re.I)
+        if any(reEfi.search(x) for x in value):
             if self.Get('cl_client_type') == 'gui':
                 raise VariableError(
                     _("Please specify EFI partition by UEFI parameter in "
